==> zio-aws-ec2_2.12-7.21.15.2-sources.jar: zio/aws/ec2/model/ModifyAddressAttributeRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.AllocationId
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ModifyAddressAttributeRequest(
    allocationId: AllocationId,
    domainName: Optional[String] = Optional.Absent,
    dryRun: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.ModifyAddressAttributeRequest = {
    import ModifyAddressAttributeRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.ModifyAddressAttributeRequest
      .builder()
      .allocationId(AllocationId.unwrap(allocationId): java.lang.String)
      .optionallyWith(domainName.map(value => value: java.lang.String))(
        _.domainName
      )
      .optionallyWith(dryRun.map(value => value: java.lang.Boolean))(_.dryRun)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.ModifyAddressAttributeRequest.ReadOnly =
    zio.aws.ec2.model.ModifyAddressAttributeRequest.wrap(buildAwsValue())
}
object ModifyAddressAttributeRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.ModifyAddressAttributeRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.ModifyAddressAttributeRequest =
      zio.aws.ec2.model.ModifyAddressAttributeRequest(
        allocationId,
        domainName.map(value => value),
        dryRun.map(value => value)
      )
    def allocationId: AllocationId
    def domainName: Optional[String]
    def dryRun: Optional[Boolean]
    def getAllocationId: ZIO[Any, Nothing, AllocationId] =
      ZIO.succeed(allocationId)
    def getDomainName: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("domainName", domainName)
    def getDryRun: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("dryRun", dryRun)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.ModifyAddressAttributeRequest
  ) extends zio.aws.ec2.model.ModifyAddressAttributeRequest.ReadOnly {
    override val allocationId: AllocationId =
      zio.aws.ec2.model.primitives.AllocationId(impl.allocationId())
    override val domainName: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.domainName())
      .map(value => value: String)
    override val dryRun: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.dryRun())
      .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.ModifyAddressAttributeRequest
  ): zio.aws.ec2.model.ModifyAddressAttributeRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-ec2_2.13-5.17.102.8-sources.jar: zio/aws/ec2/model/ModifyAddressAttributeRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.AllocationId
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ModifyAddressAttributeRequest(
    allocationId: AllocationId,
    domainName: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.ModifyAddressAttributeRequest = {
    import ModifyAddressAttributeRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.ModifyAddressAttributeRequest
      .builder()
      .allocationId(AllocationId.unwrap(allocationId): java.lang.String)
      .optionallyWith(domainName.map(value => value: java.lang.String))(
        _.domainName
      )
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.ModifyAddressAttributeRequest.ReadOnly =
    zio.aws.ec2.model.ModifyAddressAttributeRequest.wrap(buildAwsValue())
}
object ModifyAddressAttributeRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.ModifyAddressAttributeRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.ModifyAddressAttributeRequest =
      zio.aws.ec2.model.ModifyAddressAttributeRequest(
        allocationId,
        domainName.map(value => value)
      )
    def allocationId: AllocationId
    def domainName: Option[String]
    def getAllocationId: ZIO[Any, Nothing, AllocationId] =
      ZIO.succeed(allocationId)
    def getDomainName: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("domainName", domainName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.ModifyAddressAttributeRequest
  ) extends zio.aws.ec2.model.ModifyAddressAttributeRequest.ReadOnly {
    override val allocationId: AllocationId =
      zio.aws.ec2.model.primitives.AllocationId(impl.allocationId())
    override val domainName: Option[String] =
      scala.Option(impl.domainName()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.ModifyAddressAttributeRequest
  ): zio.aws.ec2.model.ModifyAddressAttributeRequest.ReadOnly = new Wrapper(
    impl
  )
}
